/*
 *============================================================================
 * blitfuncdecl.h
 *   this file lists all the different blitter funcs, and some attribute
 *   codes for each.  This is included two different places with two
 *   different definitions for the DECLARE_BLITTER macro.  One place
 *   it generates all the function prototypes in blitfuncs.h, the other
 *   place it fills in a big table of all the function pointers in 
 *   imdbgdisplay.c.
 *============================================================================
 *  Copyright 2002 
 *        William Baxter
 *        The University of North Carolina at Chapel Hill
 * 
 *  Permission to use, copy, modify, distribute and sell this software
 *  and its documentation for any purpose is hereby granted without
 *  fee, provided that the above copyright notice appear in all copies
 *  and that both that copyright notice and this permission notice
 *  appear in supporting documentation.  Binaries may be compiled with
 *  this software without any royalties or restrictions.
 * 
 *  The University of North Carolina at Chapel Hill makes no
 *  representations about the suitability of this software for any
 *  purpose. It is provided "as is" without express or implied
 *  warranty.
 *============================================================================
 */
//----------------------------------------------------------------------------
// STRETCH BLIT FUNCTIONS
//----------------------------------------------------------------------------


// Attribs legend:
// z - zoomed (stretched)
// s - scaled
// b - biased
// 8 -  8 bit channels
// 6 - 16 bit channels
// 2 - 32 bit channels
// 4 - 64 bit channels
// n - nonuniform sized channels, but byte-aligned pixels
// i - int channels
// f - float channels

DECLARE_BLITTER(stretchBlitCoreRGBA8i,  z8i)
DECLARE_BLITTER(stretchBlitCoreRGBA16i, z6i)
DECLARE_BLITTER(stretchBlitCoreRGBA32i, z2i)
DECLARE_BLITTER(stretchBlitCoreRGBA32f, z2f)
DECLARE_BLITTER(stretchBlitCoreRGBA64f, z4f)
DECLARE_BLITTER(stretchBlitCoreRGBAByteColsBitOffsetsi, zni)

// WITH SCALE
DECLARE_BLITTER(stretchBlitSCoreRGBA8i,  zs8i)
DECLARE_BLITTER(stretchBlitSCoreRGBA16i, zs6i)
DECLARE_BLITTER(stretchBlitSCoreRGBA32i, zs2i)
DECLARE_BLITTER(stretchBlitSCoreRGBA32f, zs2f)
DECLARE_BLITTER(stretchBlitSCoreRGBA64f, zs4f)
DECLARE_BLITTER(stretchBlitSCoreRGBAByteColsBitOffsetsi, zsni)

// WITH BIAS
DECLARE_BLITTER(stretchBlitBCoreRGBA8i,  zb8i)
DECLARE_BLITTER(stretchBlitBCoreRGBA16i, zb6i)
DECLARE_BLITTER(stretchBlitBCoreRGBA32i, zb2i)
DECLARE_BLITTER(stretchBlitBCoreRGBA32f, zb2f)
DECLARE_BLITTER(stretchBlitBCoreRGBA64f, zb4f)
DECLARE_BLITTER(stretchBlitBCoreRGBAByteColsBitOffsetsi, zbni)

// WITH SCALE & BIAS
DECLARE_BLITTER(stretchBlitSBCoreRGBA8i,  zsb8i)
DECLARE_BLITTER(stretchBlitSBCoreRGBA16i, zsb6i)
DECLARE_BLITTER(stretchBlitSBCoreRGBA32i, zsb2i)
DECLARE_BLITTER(stretchBlitSBCoreRGBA32f, zsb2f)
DECLARE_BLITTER(stretchBlitSBCoreRGBA64f, zsb4f)
DECLARE_BLITTER(stretchBlitSBCoreRGBAByteColsBitOffsetsi, zsbni)


/*
void stretchBlitCoreIrregulari()
void stretchBlitCoreIrregularf()
void stretchBlitCoreIrregularMix()
*/

//----------------------------------------------------------------------------
// STRAIGHT BLIT FUNCTIONS (NO STRETCH)
//----------------------------------------------------------------------------

// PLAIN
DECLARE_BLITTER(blitCoreRGBA8i,  8i)
DECLARE_BLITTER(blitCoreRGBA16i, 6i)
DECLARE_BLITTER(blitCoreRGBA32i, 2i)
DECLARE_BLITTER(blitCoreRGBA32f, 2f)
DECLARE_BLITTER(blitCoreRGBA64f, 4f)
DECLARE_BLITTER(blitCoreRGBAByteColsBitOffsetsi, ni)

// WITH SCALE
DECLARE_BLITTER(blitSCoreRGBA8i,  s8i)
DECLARE_BLITTER(blitSCoreRGBA16i, s6i)
DECLARE_BLITTER(blitSCoreRGBA32i, s2i)
DECLARE_BLITTER(blitSCoreRGBA32f, s2f)
DECLARE_BLITTER(blitSCoreRGBA64f, s4f)
DECLARE_BLITTER(blitSCoreRGBAByteColsBitOffsetsi, sni)

// WITH BIAS
DECLARE_BLITTER(blitBCoreRGBA8i,  b8i)
DECLARE_BLITTER(blitBCoreRGBA16i, b6i)
DECLARE_BLITTER(blitBCoreRGBA32i, b2i)
DECLARE_BLITTER(blitBCoreRGBA32f, b2f)
DECLARE_BLITTER(blitBCoreRGBA64f, b4f)
DECLARE_BLITTER(blitBCoreRGBAByteColsBitOffsetsi, bni)

// WITH SCALE & BIAS
DECLARE_BLITTER(blitSBCoreRGBA8i,  sb8i)
DECLARE_BLITTER(blitSBCoreRGBA16i, sb6i)
DECLARE_BLITTER(blitSBCoreRGBA32i, sb2i)
DECLARE_BLITTER(blitSBCoreRGBA32f, sb2f)
DECLARE_BLITTER(blitSBCoreRGBA64f, sb4f)
DECLARE_BLITTER(blitSBCoreRGBAByteColsBitOffsetsi, sbni)
